@@ -33,7 +33,8 @@ class EventProducer(object):
         if self.logger is not None:
             params = {"correlation_id": self.corr_id,
                       "queue_name": queue_name,
-                      "service_name": self.service_name
+                      "service_name": self.service_name,
+                      "task_type": 'start'
                       }
             requests.post(self.logger, json=params)
 
@@ -50,4 +51,12 @@ class EventProducer(object):
         while self.response is None:
             self.connection.process_data_events()
 
+        if self.logger is not None:
+            params = {"correlation_id": self.corr_id,
+                      "queue_name": queue_name,
+                      "service_name": self.service_name,
+                      "task_type": 'end'
+                      }
+            requests.post(self.logger, json=params)
+
         return self.response
