@@ -25,20 +25,29 @@ class EventReceiver(object):
 
     def on_request(self, ch, method, props, body):
         service_instance = self.service_worker()
-        response, task_type = service_instance.call(body)
 
         if self.logger is not None:
             params = {"correlation_id": props.correlation_id,
                       "queue_name": self.queue_name,
                       "service_name": self.service_name,
-                      "task_type": task_type
+                      "task_type": 'start'
                       }
             requests.post(self.logger, json=params)
 
+        response, task_type = service_instance.call(body)
+
         ch.basic_publish(exchange='',
                          routing_key=props.reply_to,
                          properties=pika.BasicProperties(correlation_id=props.correlation_id),
                          body=response)
         ch.basic_ack(delivery_tag=method.delivery_tag)
 
+        if self.logger is not None:
+            params = {"correlation_id": props.correlation_id,
+                      "queue_name": self.queue_name,
+                      "service_name": self.service_name,
+                      "task_type": 'end'
+                      }
+            requests.post(self.logger, json=params)
+
         print('Processed request:', task_type)
